from distutils.core import setup
setup(
  name = 'kedsort',
  packages = ['kedsort'], # this must be the same as the name above
  version = '0.1.8',
  description = 'sort pdfs',
  author = 'Andy Gimma',
  author_email = 'andy.n.gimma@gmail.com',
  url = 'https://github.com/andygimma/pdfsort_cli', # use the URL to the github repo
  download_url = 'https://github.com/andygimma/pdfsort_cli/archive/0.1.tar.gz', # I'll explain this in a second
  keywords = ['pdf'],
  classifiers = [],
)
